import {
  Controller,
  Post,
  Body,
  UsePipes,
  Get,
  UseGuards,
  Param,
} from '@nestjs/common';

import { TaskService } from './task.service';
import { CreateTaskDTO, EditTaskDTO } from './task.dto';
import { AuthGuard } from '../shared/auth.guard';
import { Roles } from '../shared/roles.decorator';
import { ValidationPipe } from '../shared/validation.pipe';
import { User } from 'src/user/user.decorator';

@Controller('task')
export class TaskController {
  constructor(private taskService: TaskService) {}

  // creates a new task if the user has admin role in the game
  // :id is the id of the game
  @Post('new-task/:id')
  @Roles('admin')
  @UsePipes(new ValidationPipe())
  async newTask(@Param('id') id: string, @Body() task: CreateTaskDTO) {
    return this.taskService.newTask(task);
  }

  // edits a created task if the user has admin role in the game
  // :id is the id of the game
  @Post('edit-task/:id')
  @Roles('admin')
  @UsePipes(new ValidationPipe())
  async editTask(@Param('id') id: string, @Body() data: EditTaskDTO) {
    return this.taskService.editTask(data);
  }

  @Get('get-tasks/:id')
  @UseGuards(new AuthGuard())
  async fetchTasks(@User('id') person, @Param('id') id: string) {
    return this.taskService.fetchTasks(person, id);
  }
}
